@@ -7,6 +7,7 @@ import win32con
 import win32gui
 import win32api
 import webbrowser
+import simpleaudio as sa
 import os
 import subprocess
 from xyw_macro.macro import Macro
@@ -306,7 +307,10 @@ def change_window_alpha():
     hwnd = win32gui.GetForegroundWindow()
     win32gui.SetWindowLong(hwnd, win32con.GWL_EXSTYLE,
                            win32gui.GetWindowLong(hwnd, win32con.GWL_EXSTYLE) | win32con.WS_EX_LAYERED)
-    tem = win32gui.GetLayeredWindowAttributes(hwnd)
+    try:
+        tem = win32gui.GetLayeredWindowAttributes(hwnd)
+    except Exception:
+        tem = (0, 0, 0)
     if tem[2] == win32con.LWA_ALPHA:
         alpha = tem[1]
     else:
@@ -315,6 +319,17 @@ def change_window_alpha():
     win32gui.SetLayeredWindowAttributes(hwnd, 0, alpha, win32con.LWA_ALPHA)
 
 
+def play_wave(wave_path):
+    """
+    播放音频
+    :param wave_path: 音频地址
+    :return:
+    """
+    wave_obj = sa.WaveObject.from_wave_file(wave_path)
+    play_obj = wave_obj.play()
+    play_obj.wait_done()
+
+
 if __name__ == '__main__':
     # print(random_sleep(0.2, 0.25))
     # print(get_clipboard_files())
@@ -332,4 +347,5 @@ if __name__ == '__main__':
     # change_to_en()
     # change_language_layout(-0x1fddf7fc)
     # enable_network_adapter('本地连接')
-    disable_network_adapter('本地连接')
+    # disable_network_adapter('本地连接')
+    play_wave('../警报声.wav')
